function storyPosition(){
	var elements = [];

	var contents = document.getElementsByClassName('html-content-mix');
	for (var i = 0; i < contents.length; i++) {
		var content = contents[i];
		var type = content.getAttribute('data-type');
		switch (type) {
			case 'image':
				parseImage(content, elements);
				break;
			case 'app':
				parseApp(content, elements);
				break;
			case 'video':
				parseVideo(content, elements);
				break;
			case 'album':
				parseAlbum(content, elements);
				break;
		}
	}

	window.javaFunc.replaceElement(JSON.stringify(elements));
};

function parseImage(img, elements) {
	var _left = img.getBoundingClientRect().left + img.scrollLeft;
    var _top = img.getBoundingClientRect().top + img.scrollTop;
    var _width = img.getBoundingClientRect().right - _left;
    var _height = img.getBoundingClientRect().bottom - _top;

    var imageType = img.getAttribute('data-original-format');
    var _type = 'image';

    var _leftTop = 0;
    var _rightTop = 0;
    var _rightBottom = 0;
    var _leftBottom = 0;

    var _radius = img.getAttribute('data-border-radius');
    if (_radius) {
      var _radiusArray = _radius.split(",");
      if (_radiusArray){
       _leftTop = _radiusArray[0];
       _rightTop = _radiusArray[1];
       _rightBottom = _radiusArray[2];
       _leftBottom = _radiusArray[3];
      }
    }

    var _src = img.getAttribute('data-url');
    if(imageType == 'gif'){
      _type = 'gif';
    }

    elements.push({
        type: _type,
        left : _left,
        top : _top,
        width : _width,
        height : _height,
        src : _src,
        params : {
        	img : {
        		url : _src,
            medium_url : img.getAttribute('data-medium-url'),
            original_url : img.getAttribute('data-original-url'),
            original_size : img.getAttribute('data-original-size'),
            original_format : imageType,
            gif_url : img.getAttribute('data-gif-url'),
            width : img.getAttribute('data-width'),
            height : img.getAttribute('data-height'),
            color : img.getAttribute('data-color')
        	},
        	leftTopRadius: _leftTop,
        	rightTopRadius: _rightTop,
        	rightBottomRadius: _rightBottom,
        	leftBottomRadius: _leftBottom,
        	showVideoToggle: img.getAttribute('data-video-toggle'),
        	videoDuration: img.getAttribute('data-video-duration'),
        	url: img.getAttribute('data-href'),
        	allowShot: img.getAttribute('data-allow-expand')
        }
    });
}

function parseApp(app, elements) {
	var _left = app.getBoundingClientRect().left + app.scrollLeft;
    var _top = app.getBoundingClientRect().top + app.scrollTop;
    var _width = app.getBoundingClientRect().right - _left;
    var _height = app.getBoundingClientRect().bottom - _top;

    elements.push({
    	type:'app',
    	left : _left,
    	top : _top,
    	width : _width,
    	height : _height,
    	src : app.getAttribute('data-id')
    });
}

function parseVideo(video, elements) {
	var _left = video.getBoundingClientRect().left + video.scrollLeft;
	var _top = video.getBoundingClientRect().top + video.scrollTop;
	var _width = video.getBoundingClientRect().right - _left;
	var _height = video.getBoundingClientRect().bottom - _top;

	var _src = video.getAttribute('data-video-id');

    elements.push({
    	type:'video',
    	left : _left,
    	top : _top,
    	width : _width,
    	height : _height,
    	src : _src,
    	params : {
       		video_id : _src,
       		blur_url : video.getAttribute('data-poster-blur-url'),
       		thumbnail : {
	       		url : video.getAttribute('data-poster-url'),
	       		medium_url : video.getAttribute('data-poster-medium-url'),
	       		width :  video.getAttribute('data-poster-width'),
	       		height :  video.getAttribute('data-poster-height'),
	       		color :  video.getAttribute('data-poster-color')
	       	}
	       }
	   });
}

function parseAlbum(album, elements) {
	var _left = album.getBoundingClientRect().left + album.scrollLeft;
    var _top = album.getBoundingClientRect().top + album.scrollTop;
    var _width = album.getBoundingClientRect().right - _left;
    var _height = album.getBoundingClientRect().bottom - _top;

    elements.push({
    	type : 'album',
        left : _left,
        top : _top,
        width : _width,
        height : _height,
        params : {
          pics : JSON.parse(album.getAttribute('data-pics'))
      	}
  	});
}